@@ -1,5 +1,5 @@
 # coding: utf-8
-from __future__ import absolute_import, unicode_literals
+from __future__ import absolute_import, unicode_literals, print_function
 
 import gc
 import os
@@ -12,7 +12,7 @@ from . import core
 
 show_default_optimize_code_points = core.show_default_optimize_code_points
 
-__version__ = '0.7.1'
+__version__ = '0.7.3'
 __doc__ = """
 VFB2UFO3
 DESCRIPTION
@@ -80,8 +80,8 @@ written in C++ and Cython. The submodules are compiled into `.pyd` extension
 modules. To recompile the submodules, the PyPi `cython` package and a compiler
 for Cython to utilize during extension module compilation will be required.
 
-The `glif.pyd` and `plist.pyd` extension modules require several DLLs included
-in the release `.zip` archive, FontLab installer, and PyPi package.
+The some extension modules compiled from C++ require several DLLs included in
+the release `.zip` archive, FontLab installer, and PyPi package.
 
 OPTIONAL
   cython
@@ -394,7 +394,8 @@ Mark feature options
 A `mark` feature can be generated on export by setting `mark_feature_generate`
 to `True`. A list of anchor names to omit (`mark_anchors_omit`) or a list of
 anchor names to include (`mark_anchors_include`) can be supplied to fine-tune
-the `mark` feature output.
+the `mark` feature output. For both anchor name lists, the corresponding
+`_<anchor name>` anchor will be added to their respective list.
 
 Group options
 Providing a FontLab-class file (`.flc`) or `groups.plist` speeds up UFO
@@ -622,7 +623,7 @@ vfb2ufo3.write_ufo(
 	)
 ```
 
-Test (~3200 glyphs @ 10,000 UPM -> 1,000 UPM), ≈1.5 sec
+Test (~3200 glyphs @ 10,000 UPM -> 1,000 UPM), <1.5 sec
 
 ```
 flc_path = <path to .flc file>
@@ -659,6 +660,16 @@ License
 Source files are covered under the MIT License.
 
 Version history
+version 0.7.3
+corrections to `mark` feature generation
+reverted to use of `"` from `'` in XML files for compatibility with makeOTF
+
+version 0.7.2
+reorganization of `.pxi` includes
+removal of `.pxd` Cython declaration files
+incorporated automatic string encoding from Python to C/C++
+more explicit Python string encoding/decoding
+
 version 0.7.1
 changes to `.ufoz` C++ code
 
